# Introduction

This is the documentation for PolicyEngine Nigeria, an open-source model of the Nigerian tax-benefit system. Below is a demo of the PolicyEngine Nigeria API.

<iframe src="https://policyengine-policyengine-ng-docsdemo-nz51nk.streamlit.app/~/+/?embed=True&embedded=True" height="600" width="800"
frameborder="0" scrolling="no"
></iframe>
